/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.web;

import org.sonar.core.batch.BatchFactory;
import org.picocontainer.DefaultPicoContainer;
import org.picocontainer.MutablePicoContainer;
import org.picocontainer.behaviors.Caching;
import org.picocontainer.lifecycle.ReflectionLifecycleStrategy;
import org.picocontainer.monitors.NullComponentMonitor;
import org.sonar.commons.database.JndiDatabaseConnector;
import org.sonar.core.batch.monitoring.MonitorImpl;
import org.sonar.core.database.EmbeddedDatabaseFactory;

import javax.servlet.ServletContextEvent;

public class Application {
  private static final Application singleton = new Application();

  protected MutablePicoContainer pico;

  private Application() {

  }


  public static Application getInstance() {
    return singleton;
  }

  public void start(ServletContextEvent event) {
    // components are started/stopped by reflection. It executed the following methods :
    ReflectionLifecycleStrategy lifecycleStrategy = new ReflectionLifecycleStrategy(new
        NullComponentMonitor(), "start", "stop", "dispose");

    // one instance per component
    pico = new DefaultPicoContainer(new Caching(), lifecycleStrategy, null)
        .addComponent(new ConfigurationFactory().getConfiguration(event))
        .addComponent(JRubyOnRailsPropertiesInjector.class)
        .addComponent(EmbeddedDatabaseFactory.class)
        .addComponent(JndiDatabaseConnector.class)
        .addComponent(BatchFactory.class)
        .addComponent(MonitorImpl.class)
        .addComponent(MavenRepositoryBuilder.class);
    pico.start();
  }

  public void stop() {
    if (pico!=null) {
      pico.stop();
    }
  }

  public MutablePicoContainer getContainer() {
    return pico;
  }
}
