/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.web;

import ch.hortis.sonar.core.repository.MavenRepository;
import org.apache.commons.configuration.Configuration;
import org.sonar.commons.database.DatabaseConnector;

import java.io.File;

public class MavenRepositoryBuilder {
  private Configuration configuration;
  private DatabaseConnector databaseConnector;
  private MavenRepository repository;

  public MavenRepositoryBuilder(Configuration configuration, DatabaseConnector databaseConnector) {
    this.configuration = configuration;
    this.databaseConnector = databaseConnector;
  }

  public void start() {
    String dialect = databaseConnector.getDialect();
    repository = new MavenRepository(dialect,  getRootDirectory(), getPublicMavenDirectory());
    try {
      repository.build();
    } catch (Exception e) {
      throw new RuntimeException( "Unable to start maven local repository", e );
    }
  }

  public void stop() {
    if (repository!=null) {
      try {
        repository.destroy();
      } catch (Exception e) {
        throw new RuntimeException( "Unable to stop maven local repository", e );
      }
    }
  }

  protected File getRootDirectory() {
    return new File(configuration.getString(WebProperties.ROOT_DIR));
  }

  protected File getPublicMavenDirectory() {
    return new File(configuration.getString(WebProperties.ROOT_PUBLIC_DIR), "maven");
  }
}
